# Examples

The following example demonstrates how to implement the SQLAlchemy History in a project:

## models.py

```python
--8<-- "docs/code/simple/models.py"
```

## main.py

```python
--8<-- "docs/code/simple/main.py"
```
